pub fn decode(input: &str) -> Result<Vec<u8>, DecodeError>Expand description
Decodes an ASCII85-encoded string into a byte vector.
Errors
Returns an error if the input data is not valid ASCII85.
See DecodeError for more information.
pub fn decode(input: &str) -> Result<Vec<u8>, DecodeError>Decodes an ASCII85-encoded string into a byte vector.
Returns an error if the input data is not valid ASCII85.
See DecodeError for more information.