convert_stone

Function convert_stone 

pub fn convert_stone(
    material: &str,
    log_missing: bool,
) -> Option<(&str, Option<&str>)>
Converts Minecraft stone materials to their Vintage Story equivalents.

The first element of the tuple is the stone type, the second is an optional variant. For example, ("cobblestone", Some("granite")) means “cobblestone (granite)”, and would be used as (for example) cobblestonestairs-granite, whereas ("quartz", None) would be used as quartzstairs.

If log_missing is true, a warning will be logged for unknown stone types.