parse_encoded_entities

Function parse_encoded_entities 

pub fn parse_encoded_entities(input: &str) -> Result<EntityMap>
Parse ASCII85-encoded Vintage Story block entity data.

Errors

Returns an error if the provided string is invalid ASCII85 (see [btoa::decode]), or if it cannot be decoded as an EntityMap by parse_entities.