parse_item_stack

Function parse_item_stack 

pub fn parse_item_stack(
    input: &mut impl Iterator<Item = u8>,
) -> Result<Option<ItemStack>>
Parses an ItemStack.

Errors

Returns an error if the input iterator is empty, or if any of the fields contain invalid values or terminate early.