parse_string

Function parse_string 

pub fn parse_string(input: &mut dyn Iterator<Item = u8>) -> Result<String>
Parses a string with a “seven bit int” length prefix.

Errors

Returns an error if the length prefix could not be parsed by parse_seven_bit_int, the length is negative, or the string contains invalid UTF-8.