pub fn convert_block(
block: &MinecraftBlockCode,
settings: &Settings,
) -> Option<(String, Option<EntityMap>)>Expand description
Converts a Minecraft block code to a Vintage Story block code.
If there is no known Vintage Story replacement for this block, returns None.
Otherwise, a tuple of (String, Option<EntityMap>) will be returned.
The first element is the block code, and the second is the
block entity properties.