ToInternal

Trait ToInternal 

pub trait ToInternal {
    // Required method
    fn to_internal(self) -> Result<Internal>;
}

Required Methods

fn to_internal(self) -> Result<Internal>

Converts the schematic to the Internal format.

Errors

Returns an error if the schematic could not be converted to the internal format. This may happen if the schematic contains invalid blocks or blocks with invalid properties.

Implementors