pub trait ToInternal { // Required method fn to_internal(self) -> Result<Internal>; }
Converts the schematic to the Internal format.
Internal
Returns an error if the schematic could not be converted to the internal format. This may happen if the schematic contains invalid blocks or blocks with invalid properties.